==> xplr-0.15.0.tar.gz: xplr-0.15.0/README.md <==
<h1 align="center">
  ▸[<a href="https://github.com/sayanarijit/xplr/blob/main/assets/icon/xplr.svg" target="_blank"><img src="https://s3.gifyu.com/images/xplr32.png" alt="▓▓" height="20" width="20" /></a> xplr]
</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr" target="_blank">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://github.com/sayanarijit/xplr/commits" target="_blank">
<img src="https://img.shields.io/github/commit-activity/m/sayanarijit/xplr" />
</a>

<a href="https://discord.gg/JmasSPCcz3" target="_blank">
<img src="https://img.shields.io/discord/834369918312382485?logo=discord&style=social" />
</a>

</p>

<p align="center">
<img src="https://s3.gifyu.com/images/xplr-0.5.0.gif" />
</p>

`xplr` is a terminal UI based file explorer that aims to increase our terminal
productivity by being a flexible, interactive orchestrator for the ever growing
awesome command-line utilities that work with the file-system.

To achieve its goal, `xplr` strives to be a fast, minimal and more importantly,
hackable file explorer.

`xplr` is not meant to be a replacement for the standard shell commands or the
GUI file managers. Rather, it aims to integrate them all and expose an
intuitive, scriptable, keyboard controlled, real-time visual interface, also
being an ideal candidate for further integration, enabling the users to achieve
insane terminal productivity.

Table of content
----------------

- [Introduction](https://xplr.dev/en/introduction.html)
- [Quickstart](https://xplr.dev/en/quickstart.html)
  - [Install](https://xplr.dev/en/install.html)
  - [Post Install](https://xplr.dev/en/post-install.html)
- [Configuration](https://xplr.dev/en/configuration.html)
  - [General Config](https://xplr.dev/en/general-config.html)
  - [Modes](https://xplr.dev/en/modes.html)
  - [Message](https://xplr.dev/en/message.html)
  - [Layouts](https://xplr.dev/en/layouts.html)
  - [Node Types](https://xplr.dev/en/node_types.html)
  - [Style](https://xplr.dev/en/style.html)
  - [Sorting](https://xplr.dev/en/sorting.html)
  - [Filtering](https://xplr.dev/en/filtering.html)
  - [Column Renderer](https://xplr.dev/en/column-renderer.html)
- [Default Key Bindings](https://xplr.dev/en/default-key-bindings.html)
- [Plugin](https://xplr.dev/en/plugin.html)
  - [Installing Plugins](https://xplr.dev/en/installing-plugins.html)
  - [Writing Plugins](https://xplr.dev/en/writing-plugins.html)
  - [Awesome Plugins](https://xplr.dev/en/awesome-plugins.html)
- [Integration](https://xplr.dev/en/integration.html)
  - [Awesome Integrations](https://xplr.dev/en/awesome-integrations.html)
- [TODO](https://xplr.dev/en/todo.html)
- [Alternatives](https://xplr.dev/en/alternatives.html)
- [Upgrade Guide](https://xplr.dev/en/upgrade-guide.html)
- [Community](https://xplr.dev/en/community.html)
- [Contribute](https://xplr.dev/en/contribute.html)


Introductions & Reviews
-----------------------

- [[VIDEO] XPLR: Insanely Hackable Lua File Manager ~ Brodie Robertson](https://youtu.be/MaVRtYh1IRU)


Packaging
---------

<a href="https://repology.org/project/xplr/versions" target="_blank"><img src="https://repology.org/badge/vertical-allrepos/xplr.svg" /></a>


Backers
-------

<a href="https://opencollective.com/xplr#backer" target="_blank"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>

==> xplr-0.15.2.tar.gz: xplr-0.15.2/README.md <==
<h1 align="center">
  ▸[<a href="https://github.com/sayanarijit/xplr/blob/main/assets/icon/xplr.svg" target="_blank"><img src="https://s3.gifyu.com/images/xplr32.png" alt="▓▓" height="20" width="20" /></a> xplr]
</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr" target="_blank">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://github.com/sayanarijit/xplr/commits" target="_blank">
<img src="https://img.shields.io/github/commit-activity/m/sayanarijit/xplr" />
</a>

<a href="https://matrix.to/#/#xplr-pub:matrix.org" target="_blank">
<img alt="Matrix" src="https://img.shields.io/matrix/xplr-pub:matrix.org?color=0DB787&label=matrix&logo=Matrix">
</a>
  
<a href="https://discord.gg/JmasSPCcz3" target="_blank">
<img src="https://img.shields.io/discord/834369918312382485?color=5865F2&label=discord&logo=Discord" />
</a>

</p>

<p align="center">
<img src="https://s3.gifyu.com/images/xplr-0.5.0.gif" />
</p>

`xplr` is a terminal UI based file explorer that aims to increase our terminal
productivity by being a flexible, interactive orchestrator for the ever growing
awesome command-line utilities that work with the file-system.

To achieve its goal, `xplr` strives to be a fast, minimal and more importantly,
hackable file explorer.

`xplr` is not meant to be a replacement for the standard shell commands or the
GUI file managers. Rather, it aims to integrate them all and expose an
intuitive, scriptable, keyboard controlled, real-time visual interface, also
being an ideal candidate for further integration, enabling the users to achieve
insane terminal productivity.

Table of content
----------------

- [Introduction](https://xplr.dev/en/introduction.html)
- [Quickstart](https://xplr.dev/en/quickstart.html)
  - [Install](https://xplr.dev/en/install.html)
  - [Post Install](https://xplr.dev/en/post-install.html)
- [Configuration](https://xplr.dev/en/configuration.html)
  - [General Config](https://xplr.dev/en/general-config.html)
  - [Modes](https://xplr.dev/en/modes.html)
  - [Message](https://xplr.dev/en/message.html)
  - [Layouts](https://xplr.dev/en/layouts.html)
  - [Node Types](https://xplr.dev/en/node_types.html)
  - [Style](https://xplr.dev/en/style.html)
  - [Sorting](https://xplr.dev/en/sorting.html)
  - [Filtering](https://xplr.dev/en/filtering.html)
  - [Column Renderer](https://xplr.dev/en/column-renderer.html)
- [Default Key Bindings](https://xplr.dev/en/default-key-bindings.html)
- [Plugin](https://xplr.dev/en/plugin.html)
  - [Installing Plugins](https://xplr.dev/en/installing-plugins.html)
  - [Writing Plugins](https://xplr.dev/en/writing-plugins.html)
  - [Awesome Plugins](https://xplr.dev/en/awesome-plugins.html)
- [Integration](https://xplr.dev/en/integration.html)
  - [Awesome Integrations](https://xplr.dev/en/awesome-integrations.html)
- [TODO](https://xplr.dev/en/todo.html)
- [Alternatives](https://xplr.dev/en/alternatives.html)
- [Upgrade Guide](https://xplr.dev/en/upgrade-guide.html)
- [Community](https://xplr.dev/en/community.html)
- [Contribute](https://xplr.dev/en/contribute.html)


Introductions & Reviews
-----------------------

- [[VIDEO] XPLR: Insanely Hackable Lua File Manager ~ Brodie Robertson](https://youtu.be/MaVRtYh1IRU)


Packaging
---------

<a href="https://repology.org/project/xplr/versions" target="_blank"><img src="https://repology.org/badge/vertical-allrepos/xplr.svg" /></a>


Backers
-------

<a href="https://opencollective.com/xplr#backer" target="_blank"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>
